==> autoai_ts_libs-2.0.6-73-cp310-cp310-win_amd64.whl: autoai_ts_libs/deps/tspy/data_structures/__init__.py <==
﻿"""

"""

#  /************** Begin Copyright - Do not add comments here **************
#   * Licensed Materials - Property of IBM
#   *
#   *   OCO Source Materials
#   *
#   *   (C) Copyright IBM Corp. 2020, All Rights Reserved
#   *
#   * The source code for this program is not published or other-
#   * wise divested of its trade secrets, irrespective of what has
#   * been deposited with the U.S. Copyright Office.
#   ***************************** End Copyright ****************************/

from autoai_ts_libs.deps.tspy.data_structures.time_series import TimeSeries
from autoai_ts_libs.deps.tspy.data_structures.multi_time_series.MultiTimeSeries import MultiTimeSeries
from autoai_ts_libs.deps.tspy.data_structures.observations.BoundTimeSeries import BoundTimeSeries
from autoai_ts_libs.deps.tspy.data_structures.observations.Segment import Segment
from autoai_ts_libs.deps.tspy.data_structures.observations.Observation import Observation
from autoai_ts_libs.deps.tspy.data_structures.observations.TRS import TRS
from autoai_ts_libs.deps.tspy.data_structures.forecasting.Prediction import Prediction
from .Stats import Stats
from autoai_ts_libs.deps.tspy.data_structures.time_series.SegmentTimeSeries import SegmentTimeSeries
from autoai_ts_libs.deps.tspy.data_structures.multi_time_series.SegmentMultiTimeSeries import SegmentMultiTimeSeries

__all__ = ['TimeSeries.py', 'MultiTimeSeries', 'Observation', 'BoundTimeSeries', 'Segment', 'Stats', 'TRS',
           'Prediction']
__all__ += ['SegmentTimeSeries2', 'SegmentMultiTimeSeries2']

==> autoai_ts_libs-3.0.4-144-cp310-cp310-win_amd64.whl: autoai_ts_libs/deps/tspy/data_structures/__init__.py <==
﻿"""

"""

#  /************** Begin Copyright - Do not add comments here **************
#   * Licensed Materials - Property of IBM
#   *
#   *   OCO Source Materials
#   *
#   *   (C) Copyright IBM Corp. 2020, All Rights Reserved
#   *
#   * The source code for this program is not published or other-
#   * wise divested of its trade secrets, irrespective of what has
#   * been deposited with the U.S. Copyright Office.
#   ***************************** End Copyright ****************************/

from autoai_ts_libs.deps.tspy.data_structures.time_series.TimeSeries import TimeSeries
from autoai_ts_libs.deps.tspy.data_structures.multi_time_series.MultiTimeSeries import MultiTimeSeries
from autoai_ts_libs.deps.tspy.data_structures.observations.BoundTimeSeries import BoundTimeSeries
from autoai_ts_libs.deps.tspy.data_structures.observations.Segment import Segment
from autoai_ts_libs.deps.tspy.data_structures.observations.Observation import Observation
from autoai_ts_libs.deps.tspy.data_structures.observations.TRS import TRS
from autoai_ts_libs.deps.tspy.data_structures.forecasting.Prediction import Prediction
from .Stats import Stats
from autoai_ts_libs.deps.tspy.data_structures.time_series.SegmentTimeSeries import SegmentTimeSeries
from autoai_ts_libs.deps.tspy.data_structures.multi_time_series.SegmentMultiTimeSeries import SegmentMultiTimeSeries

__all__ = ['TimeSeries.py', 'MultiTimeSeries', 'Observation', 'BoundTimeSeries', 'Segment', 'Stats', 'TRS',
           'Prediction']
__all__ += ['SegmentTimeSeries2', 'SegmentMultiTimeSeries2']
